import structlog
import uuid


class DjangoCorelationMiddleware(object):
    CORELATED_HEADER = "HTTP_X_CO_REQUEST_ID"

    def __init__(self, app):
        self.app = app
        structlog.configure(
            processors=[
                structlog.processors.TimeStamper(fmt="ISO"),
                structlog.processors.JSONRenderer(),
            ],
            context_class=structlog.threadlocal.wrap_dict(dict),
            wrapper_class=structlog.stdlib.BoundLogger,
            cache_logger_on_first_use=True,
        )

    def process_request(self, request):

        logger = structlog.getLogger()
        if request.headers.get(self.CORELATED_HEADER):
            current_request_id = request.headers.get(self.CORELATED_HEADER)

        else:
            current_request_id = str(uuid.uuid4())
        logger = logger.bind(request_id=current_request_id)



import logging

import structlog
import wrapt
import uuid

logger = logging.getLogger()


def patch():
    wrapt.wrap_function_wrapper("kombu", "messaging.Producer.publish", _inject_header)


def _inject_header(wrapped, instance, args, kwargs):
    if "headers" in kwargs:
        headers = kwargs["headers"]
    else:
        headers = {}

    try:
        headers["X_CO_REQUEST_ID"] = str(
            structlog.get_config()["context_class"]._tl.dict_["request_id"]
        )
    except Exception as e:
        headers["X_CO_REQUEST_ID"] = str(uuid.uuid4())
    kwargs["headers"] = headers
    return wrapped(*args, **kwargs)



import uuid

import structlog


class FlaskCorelationMiddleWare(object):
    """
    It uses structlog to maintain request_id
    """

    CORELATED_HEADER = "HTTP_X_CO_REQUEST_ID"

    def __init__(self, app):
        self.app = app
        structlog.configure(
            processors=[
                structlog.processors.TimeStamper(fmt="ISO"),
                structlog.processors.JSONRenderer(),
            ],
            context_class=structlog.threadlocal.wrap_dict(dict),
            wrapper_class=structlog.stdlib.BoundLogger,
            cache_logger_on_first_use=True,
        )

    def __call__(self, environ, start_response):

        logger = structlog.getLogger()
        if self.CORELATED_HEADER in environ:
            current_request_id = environ[self.CORELATED_HEADER]

        else:
            current_request_id = str(uuid.uuid4())
        logger = logger.bind(request_id=current_request_id)
        return self.app(environ, start_response)



from setuptools import setup, find_packages

setup(
    name="corelated_logs",
    version="0.0.6",
    packages=find_packages(exclude=["tests"]),
    install_requires=["structlog==18.2.0", "wrapt==1.10.11", "pre-commit-hooks==1.4.0"],
    url="",
    license="BSD",
    author="sohit kumar",
    author_email="sumitk002@gmail.com",
    test_suite="tests",
    description="A python library to generate corelation id and bind it to headers in outgoing request",
)
